- Add module ``xoutil.future.csv``.

- Add module ``xoutil.future.mimetypes``.

- Add module ``xoutil.eight.urllib``.

- The module ``xoutil.iterators`` is now officially named
  ``xoutil.future.itertools``.  The alias ``xoutil.iterators`` remains as a
  deprecated alias.

- Add ``xoutil.future.itertools.merge``.

- Add ``xoutil.future.types._get_mro_attr`` function.

- Deprecate in ``xoutil.future.types`` module: ``mro_dict`` class; and the
  functions ``mro_get_value_list``, ``mro_get_full_mapping``, ``is_iterable``,
  ``is_collection``, ``is_mapping``, ``is_string_like``, ``is_scalar``,
  ``is_module``, ``are_instances``, and ``no_instances``.
